uploads.Upload (Upload file) — amici1

# `uploads.Upload` (Upload file)

Upload(id, user, file, mimetype, file_size, owner_type, owner_id, upload_area, type, volume, library_file, description)

Master tables : uploads.AllUploads (Upload files), uploads.AreaUploads (Upload files), uploads.MyUploads (My Upload files), uploads.Uploads (Upload files)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Uploaded by (user) : The author of this object. A pointer to lino.modlib.users.models.User.

- File (file) : Pointer to the uploaded file itself (a Django FileField).

- MIME type (mimetype) : The media type of the uploaded file.

- File size (file_size) : The size of the file in bytes. Not yet implemented.

- Controlled by (type) (owner_type) : See `<django.db.models.fields.related.ForeignKey: owner_type>`.

- Controlled by (object) (owner_id) : See `<lino.modlib.gfks.fields.GenericForeignKeyIdField: owner_id>`.

- Upload area (upload_area) : The upload area this file belongs to.

- Upload type (type) : The type of this upload.

- Library volume (volume) : A pointer to the library volume where this file is stored.

- Library file (library_file) : The path of this file, relative the volume’s root.

- Description (description) : A short description entered manually by the user.

- Description (description_link) : Almost the same as description, but if file is not empty, the text is clickable, and clicking on it opens the uploaded file in a new browser window.

- Name (name_column) : See `lino.modlib.uploads.models.Upload.name_column`.

- (None) (navigation_panel) : See `lino.modlib.uploads.models.Upload.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino.modlib.uploads.models.Upload.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
user | Uploaded by | The author of this object. A pointer to lino.modlib.users.models.User.
file | File | Pointer to the uploaded file itself (a Django FileField).
mimetype | MIME type | The media type of the uploaded file.
file_size | File size | The size of the file in bytes. Not yet implemented.
owner_type | Controlled by (type) |
owner_id | Controlled by (object) |
upload_area | Upload area | The upload area this file belongs to.
type | Upload type | The type of this upload.
volume | Library volume | A pointer to the library volume where this file is stored.
library_file | Library file | The path of this file, relative the volume’s root.
description | Description | A short description entered manually by the user.
owner | Controlled by |
description_link | Description | Almost the same as description, but if file is not empty, the text is clickable, and clicking on it opens the uploaded file in a new browser window.
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |